''' Third party package integrations '''
import os
import sys
import shutil

def create_or_append_config(location, name=False):
    if name:
        file_name = name
    else:
        file_name = os.path.basename(location)

    # import it into the config directory
    config_directory = os.path.join(os.getcwd(), 'config')

    # if file does not exist
    if not os.path.isfile(config_directory + '/' + file_name):
        shutil.copyfile(location,
                        config_directory + '/' + file_name)
        print('\033[92mConfiguration File Created!\033[0m')
    else:
        ## Append to the file
        # tempfiles is a list of file handles to your temp files. Order them however you like
        project_config = open(config_directory + '/' + file_name, "a")
        package_config = open(location, 'r')

        project_config.write(package_config.read())

        project_config.close()
        package_config.close()
        print('\033[92mConfiguration File Appended!\033[0m')


def append_web_routes(location):
    # import it into the web.py file
    routes_file = os.path.join(os.getcwd(), 'routes/web.py')

    ## Append to the file
    # tempfiles is a list of file handles to your temp files. Order them however you like
    project_routes = open(routes_file, "a")
    package_routes = open(location, 'r')

    project_routes.write(package_routes.read())

    project_routes.close()
    package_routes.close()
    print('\033[92mroutes/web.py File Appended!\033[0m')

def append_api_routes(location):
    # import it into the web.py file
    api_file = os.path.join(os.getcwd(), 'routes/api.py')

    ## Append to the file
    # tempfiles is a list of file handles to your temp files. Order them however you like
    project_routes = open(api_file, "a")
    package_routes = open(location, 'r')

    project_routes.write(package_routes.read())

    project_routes.close()
    package_routes.close()
    print('\033[92mroutes/api.py File Appended!\033[0m')


def create_controller(location):
    file_name = os.path.basename(location)

    controller_directory = os.path.join(os.getcwd(), 'app/http/controllers')
    controller_file = os.path.join(controller_directory, file_name)

    
    if os.path.isfile(controller_file):
        # if file does exist
        print('\033[91mController Already Exists!\033[0m')
    else:
        # copy controller over
        shutil.copyfile(
            location,
            controller_file
        )
        print('\033[92mController Created\033[0m')



''' Billable Model which can be added to a user model to charge users '''
from peewee import Model, CharField
import stripe
from config import payment

if payment.DRIVER == 'stripe':
    stripe.api_key = payment.PROCESSORS['stripe']['secret']

class Billable(Model):
    ''' Billable model used for model extensions '''
    stripe_token = CharField(default='')
    stripe_customer_id = CharField(default='')
    payment_processor = CharField(default='')

    def charge(self, amount, token):
        ''' Charge the user with a certain amount '''
        charge = stripe.Charge.create(
            amount=amount,
            currency="usd",
            source=token,  # obtained with Stripe.js
            description="Charge for " + self.email
        )

        query = self.update(
            stripe_token=token,
            payment_processor=payment.DRIVER,
            stripe_customer_id=charge.id).where(self.id == self.id)
        query.execute()



from config import storage, application
import os
import sass

class Storage(object):

    def __init__(self):
        pass

    def compile_sass(self):
        matches = []
        for files in storage.SASSFILES['importFrom']:
            for root, dirnames, filenames in os.walk(os.path.join(application.BASE_DIRECTORY, files)):
                for filename in filenames:
                    if filename.endswith(('.sass', '.scss')) and not filename.startswith('_'):
                        matches.append(os.path.join(root, filename))

        for filename in matches:
            with open(filename) as f:
                compiled_sass = sass.compile(
                    string=f.read(), include_paths=storage.SASSFILES['includePaths']
                )
                name = filename.split(os.sep)[-1].replace('.scss', '').replace('.sass', '')
                write_file = os.path.join(os.path.join(application.BASE_DIRECTORY, 
                    storage.SASSFILES['compileTo']), '{0}.css'.format(name))
            with open(write_file, 'w') as r:
                r.write(compiled_sass)



from distutils.core import setup
setup(
    name='masonite',
    packages=['masonite',
              'masonite.auth',
              'masonite.cashier',
              'masonite.extensions',
              'masonite.facades',
             ],  # this must be the same as the name above
    version='0.2.5.3',
    description='The core for the python framework',
    author='Joseph Mancuso',
    author_email='idmann509@gmail.com',
    url='https://github.com/josephmancuso/masonite',  # use the URL to the github repo
    download_url='',
    keywords=['python web framework', 'python3'],  # arbitrary keywords
    classifiers=[],
)
